commit:     58d33c66211296950837c243ef27d6abb42ff2de
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Aug  3 09:54:50 2025 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Aug  3 09:54:50 2025 +0000
URL:        https://gitweb.gentoo.org/repo/proj/prefix.git/commit/?id=58d33c66

scripts/bootstrap-prefix: fix disabling CET for binutils and add zstd

stage2:
libzstd needs not to be provided by the host, so don't require it
mask the USE-flags so they don't come up when the build enables them

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 scripts/bootstrap-prefix.sh | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/scripts/bootstrap-prefix.sh b/scripts/bootstrap-prefix.sh
index 3ba3a1b660..2ccdf2dd28 100755
--- a/scripts/bootstrap-prefix.sh
+++ b/scripts/bootstrap-prefix.sh
@@ -2086,9 +2086,11 @@ bootstrap_stage2() {
                echo "sys-devel/gcc -pie" >> 
"${ROOT}"/tmp/etc/portage/package.use
        fi
 
-       # don't use CET, we don't know if the host compiler supports it
-       echo "sys-devel/binutils -cet" >> \
+       # don't use CET/ZSTD, we don't know if the host (and compiler) supports 
it
+       echo "sys-devel/binutils -cet -zstd" >> \
                "${ROOT}"/tmp/etc/portage/profile/package.use.force
+       echo "sys-devel/binutils-cet zstd" >> \
+               "${ROOT}"/tmp/etc/portage/profile/package.use.mask
 
        emerge_pkgs --nodeps "${pkgs[@]}" || return 1
 

Reply via email to